@@ -1,33 +1,24 @@
 from . import PIL  # noqa: F401
-from . import botocore  # noqa: F401
+from . import automissing  # noqa: F401
+from . import autopackages  # noqa: F401
 from . import ctypes  # noqa: F401
 from . import docutils  # noqa: F401
 from . import ftplib  # noqa: F401
-from . import importlib  # noqa: F401
 from . import lxml  # noqa: F401
 from . import matplotlib  # noqa: F401
-from . import mimetypes  # noqa: F401
-from . import numpy  # noqa: F401
-from . import os_module  # noqa: F401
 from . import pydoc  # noqa: F401
 from . import pyenchant  # noqa: F401
 from . import pygame  # noqa: F401
 from . import pyopengl  # noqa: F401
 from . import pyside  # noqa: F401
 from . import pyside2  # noqa: F401
-from . import pyzmq  # noqa: F401
 from . import qt5  # noqa: F401
-from . import re  # noqa: F401
-from . import scipy  # noqa: F401
 from . import setuptools  # noqa: F401
 from . import shiboken2  # noqa: F401
 from . import sip  # noqa: F401
 from . import six  # noqa: F401
-from . import subprocess  # noqa: F401
 from . import sysconfig_module  # noqa: F401
 from . import tkinter  # noqa: F401
-from . import uuid  # noqa: F401
 from . import virtualenv  # noqa: F401
 from . import wx  # noqa: F401
 from . import xml  # noqa: F401
-from . import pycryptodome  # noqa: F401
