@@ -6,13 +6,13 @@ def function():
 
 def import_module(name):
     try:
-        exec ("import %s"%(name,))
+        exec("import %s"%(name,))
         m = eval(name)
-    except ImportError:
-        print ("* import failed")
+    except ImportError as exc:
+        print("* import failed: %s path: %s"%(exc, sys.path))
 
     else:
-        print m.__name__
+        print(m.__name__)
 
 def print_path():
     print(sys.path)
@@ -29,7 +29,7 @@ if __name__ == "__main__":
             raise
 
         except Exception:
-            print ("* Exception " + str(sys.exc_info()[1]))
+            print("* Exception " + str(sys.exc_info()[1]))
 
         sys.stdout.flush()
         sys.stderr.flush()
